Documentation
¶
Overview ¶
Package bot provides a Go browser automation framework focused on Chromium-compatible browsers driven through the Chrome DevTools Protocol.
The public package is a small facade over the internal implementation so the import path stays stable while the implementation can evolve internally.
Code generated by go-bot package facade; DO NOT EDIT.
Index ¶
- Constants
- Variables
- type ActionChain
- type AfterClickHook
- type ArtifactsLevel
- type BatchEval
- type BatchEvalItem
- type BatchEvalOp
- type BatchEvalResult
- type BeforeNavigateHook
- type Browser
- type BrowserPool
- type BrowserPoolFactory
- type BrowserPoolHealthCheck
- type BrowserPoolOption
- type BrowserPoolOptions
- type BrowserPoolStats
- type CDPBudgetStats
- type CDPControlPath
- type CDPReconnectStats
- type CDPSessionKind
- type CDPTransportStats
- type CallRetryMode
- type Capabilities
- type CleanupPolicy
- type ClickOption
- type ClickOptions
- type CloseAction
- type CloseReport
- type Config
- type ConsoleMessage
- type Context
- type ContextOption
- type ContextOptions
- type ContinueOption
- type ContinueOptions
- type Cookie
- type CookieCleanupPreset
- type CookieInput
- type CookieSelector
- type DialogEvent
- type DownloadEvent
- type DownloadManager
- type Element
- type ElementWaiter
- type EmulatedColorScheme
- type EmulatedForcedColors
- type EmulatedReducedMotion
- type EmulationManager
- type Engine
- type EngineDiagnostics
- type EngineOwnership
- type EnvProfile
- type ExposedFunction
- type FileDialogEvent
- type FingerprintAudioOption
- type FingerprintMode
- type FingerprintWebRTCMode
- type Frame
- type FulfillResponse
- type Geolocation
- type GotoOption
- type GotoOptions
- type HistoryLimits
- type IndexedDBDatabase
- type IndexedDBRecord
- type IndexedDBScope
- type InterceptEvent
- type InterceptFilter
- type InterceptHandler
- type InterceptManager
- type InterceptOption
- type InterceptOptions
- type InterceptPhase
- type InterceptedRequest
- type InternalOpStats
- type LaunchArgsPolicy
- type LaunchMode
- type LaunchOption
- type LoadState
- type Meta
- type MobilePreset
- type MonitorServeOption
- type MonitorServeOptions
- type MonitorServer
- type MonitorSnapshot
- type MouseButton
- type NavigationAction
- type NavigationEvent
- type NavigationManager
- type NetworkFilter
- type NetworkManager
- type NetworkPacket
- type NetworkResponseData
- type NetworkTransaction
- type PDFOption
- type PDFOptions
- type PacketType
- type Page
- type PageCreatedHook
- type PageDiagnostics
- type PageEnvironment
- type PageHooks
- type PageInteraction
- type PageLifecycle
- type PageManagers
- type PageNavigation
- type PageNetworkControl
- type PageOption
- type PageOptions
- type PageQuery
- type PageTabs
- type PageWaiter
- type PiercingBox
- type PiercingNode
- type Point
- type PooledEngine
- type PressOption
- type PressOptions
- type Protocol
- type ProtocolEvent
- type RaceBuilder
- type RaceElementBuilder
- type RaceResult
- type RawBridge
- type ReconnectPolicy
- type Rect
- type RedirectResponse
- type RequestEvent
- type ResponseEvent
- type RetryPolicy
- type RoleOption
- type RoleOptions
- type Route
- type RouteHandler
- type RoutePauseStage
- type ScreenshotOption
- type ScreenshotOptions
- type ScriptTagOption
- type ScriptTagOptions
- type SetContentOption
- type SetContentOptions
- type SignalHandlingMode
- type StorageManager
- type StorageScope
- type StyleTagOption
- type StyleTagOptions
- type Subscription
- type TraceEvent
- type TraceFileOption
- type TraceFileOptions
- type TypeOption
- type TypeOptions
- type UnsupportedComboError
- type Viewport
- type WaitTask
- type WindowBounds
- type WindowManager
- type WindowState
Constants ¶
const ( ArtifactsLevelAuto = core.ArtifactsLevelAuto ArtifactsLevelFull = core.ArtifactsLevelFull ArtifactsLevelMeta = core.ArtifactsLevelMeta ArtifactsLevelMetaHTML = core.ArtifactsLevelMetaHTML AttachManaged = core.AttachManaged AttachUnmanaged = core.AttachUnmanaged BatchEvalOpAttribute = core.BatchEvalOpAttribute BatchEvalOpExists = core.BatchEvalOpExists BatchEvalOpHTML = core.BatchEvalOpHTML BatchEvalOpIsVisible = core.BatchEvalOpIsVisible BatchEvalOpText = core.BatchEvalOpText BatchEvalOpValue = core.BatchEvalOpValue BiDi = core.BiDi CDP = core.CDP CDPControlPathAuto = core.CDPControlPathAuto CDPControlPathBrowserSession = core.CDPControlPathBrowserSession CDPControlPathPageWSPrefer = core.CDPControlPathPageWSPrefer CDPSessionKindContextEphemeral = core.CDPSessionKindContextEphemeral CDPSessionKindPageAttached = core.CDPSessionKindPageAttached CDPSessionKindPageWebSocket = core.CDPSessionKindPageWebSocket CDPSessionKindUnknown = core.CDPSessionKindUnknown CallRetryAll = core.CallRetryAll CallRetryStrict = core.CallRetryStrict Chrome = core.Chrome CleanupPolicyAuto = core.CleanupPolicyAuto CleanupPolicyPreserveAll = core.CleanupPolicyPreserveAll CleanupPolicyRemoveAll = core.CleanupPolicyRemoveAll CleanupPolicyRemoveOwned = core.CleanupPolicyRemoveOwned CloseActionClose = core.CloseActionClose CloseActionDetach = core.CloseActionDetach CloseActionNone = core.CloseActionNone CloseActionShutdown = core.CloseActionShutdown CookieCleanupPresetCommonConsent = core.CookieCleanupPresetCommonConsent CookieCleanupPresetCookiebot = core.CookieCleanupPresetCookiebot CookieCleanupPresetOneTrust = core.CookieCleanupPresetOneTrust Edge = core.Edge EmulatedColorSchemeDark = core.EmulatedColorSchemeDark EmulatedColorSchemeLight = core.EmulatedColorSchemeLight EmulatedColorSchemeNoPreference = core.EmulatedColorSchemeNoPreference EmulatedColorSchemeUnset = core.EmulatedColorSchemeUnset EmulatedForcedColorsActive = core.EmulatedForcedColorsActive EmulatedForcedColorsNone = core.EmulatedForcedColorsNone EmulatedForcedColorsUnset = core.EmulatedForcedColorsUnset EmulatedReducedMotionNoPreference = core.EmulatedReducedMotionNoPreference EmulatedReducedMotionReduce = core.EmulatedReducedMotionReduce EmulatedReducedMotionUnset = core.EmulatedReducedMotionUnset FingerprintModeFixed = core.FingerprintModeFixed FingerprintModeRandom = core.FingerprintModeRandom FingerprintModeSystem = core.FingerprintModeSystem FingerprintWebRTCDisableUDP = core.FingerprintWebRTCDisableUDP FingerprintWebRTCNative = core.FingerprintWebRTCNative FingerprintWebRTCReplace = core.FingerprintWebRTCReplace Firefox = core.Firefox InterceptBeforeRequest = core.InterceptBeforeRequest InterceptResponse = core.InterceptResponse LaunchArgsPolicyManaged = core.LaunchArgsPolicyManaged LaunchArgsPolicyPassthrough = core.LaunchArgsPolicyPassthrough LaunchManaged = core.LaunchManaged LaunchModeAuto = core.LaunchModeAuto LoadStateDOMContentLoaded = core.LoadStateDOMContentLoaded LoadStateLoad = core.LoadStateLoad LoadStateNetworkIdle = core.LoadStateNetworkIdle MouseLeft = core.MouseLeft MouseMiddle = core.MouseMiddle MouseRight = core.MouseRight PacketRequest = core.PacketRequest PacketResponse = core.PacketResponse RetryAttemptsUnlimited = core.RetryAttemptsUnlimited RoutePauseStageRequest = core.RoutePauseStageRequest RoutePauseStageResponse = core.RoutePauseStageResponse RoutePauseStageUnknown = core.RoutePauseStageUnknown Safari = core.Safari SignalHandlingAuto = core.SignalHandlingAuto SignalHandlingManual = core.SignalHandlingManual SignalHandlingOff = core.SignalHandlingOff WindowStateFullscreen = core.WindowStateFullscreen WindowStateMaximized = core.WindowStateMaximized WindowStateMinimized = core.WindowStateMinimized WindowStateNormal = core.WindowStateNormal )
Variables ¶
var ( ErrClosed = core.ErrClosed ErrContextNotFound = core.ErrContextNotFound ErrElementNotFound = core.ErrElementNotFound ErrNotImplemented = core.ErrNotImplemented ErrPageNotFound = core.ErrPageNotFound ErrPoolClosed = core.ErrPoolClosed ErrProfileBusy = core.ErrProfileBusy ErrProfileInUse = core.ErrProfileInUse ErrReconnectOverflow = core.ErrReconnectOverflow ErrShadowClosed = core.ErrShadowClosed ErrStaleDevToolsPort = core.ErrStaleDevToolsPort ErrTimeout = core.ErrTimeout Attach = core.Attach ClearContextCookiePreset = core.ClearContextCookiePreset ClearPageCookiePreset = core.ClearPageCookiePreset CookieCleanupSelectors = core.CookieCleanupSelectors ExportContextCookiesToJar = core.ExportContextCookiesToJar ExportPageCookiesToJar = core.ExportPageCookiesToJar Launch = core.Launch LaunchOrAttach = core.LaunchOrAttach LaunchPersistent = core.LaunchPersistent LaunchWithAddress = core.LaunchWithAddress LaunchWithArgs = core.LaunchWithArgs LaunchWithArtifacts = core.LaunchWithArtifacts LaunchWithArtifactsDir = core.LaunchWithArtifactsDir LaunchWithArtifactsLevel = core.LaunchWithArtifactsLevel LaunchWithAutoPort = core.LaunchWithAutoPort LaunchWithBinary = core.LaunchWithBinary LaunchWithBrowser = core.LaunchWithBrowser LaunchWithCDPControlPath = core.LaunchWithCDPControlPath LaunchWithCDPMethodRateLimit = core.LaunchWithCDPMethodRateLimit LaunchWithCDPMethodRateLimits = core.LaunchWithCDPMethodRateLimits LaunchWithCDPRecord = core.LaunchWithCDPRecord LaunchWithCleanupPolicy = core.LaunchWithCleanupPolicy LaunchWithDebugPort = core.LaunchWithDebugPort LaunchWithDiagnostics = core.LaunchWithDiagnostics LaunchWithDownloadDir = core.LaunchWithDownloadDir LaunchWithDryRun = core.LaunchWithDryRun LaunchWithExistingOnly = core.LaunchWithExistingOnly LaunchWithExtensions = core.LaunchWithExtensions LaunchWithFingerprintAudio = core.LaunchWithFingerprintAudio LaunchWithFingerprintCPU = core.LaunchWithFingerprintCPU LaunchWithFingerprintCanvas = core.LaunchWithFingerprintCanvas LaunchWithFingerprintDisplay = core.LaunchWithFingerprintDisplay LaunchWithFingerprintLanguage = core.LaunchWithFingerprintLanguage LaunchWithFingerprintMemory = core.LaunchWithFingerprintMemory LaunchWithFingerprintTimezone = core.LaunchWithFingerprintTimezone LaunchWithFingerprintUILocale = core.LaunchWithFingerprintUILocale LaunchWithFingerprintWebRTC = core.LaunchWithFingerprintWebRTC LaunchWithHeadless = core.LaunchWithHeadless LaunchWithHistoryLimits = core.LaunchWithHistoryLimits LaunchWithKeepBrowserAlive = core.LaunchWithKeepBrowserAlive LaunchWithKeepUserDataDir = core.LaunchWithKeepUserDataDir LaunchWithLaunchArgsPolicy = core.LaunchWithLaunchArgsPolicy LaunchWithLeakless = core.LaunchWithLeakless LaunchWithListenerPanicThreshold = core.LaunchWithListenerPanicThreshold LaunchWithLogger = core.LaunchWithLogger LaunchWithMode = core.LaunchWithMode LaunchWithProfileDirectory = core.LaunchWithProfileDirectory LaunchWithProtocol = core.LaunchWithProtocol LaunchWithProxy = core.LaunchWithProxy LaunchWithReconnect = core.LaunchWithReconnect LaunchWithRemoteAllowOrigins = core.LaunchWithRemoteAllowOrigins LaunchWithRetryPolicy = core.LaunchWithRetryPolicy LaunchWithSignalHandling = core.LaunchWithSignalHandling LaunchWithUserDataDir = core.LaunchWithUserDataDir LoadContextCookiesFromJar = core.LoadContextCookiesFromJar LoadPageCookiesFromJar = core.LoadPageCookiesFromJar MustAttach = core.MustAttach MustLaunch = core.MustLaunch MustLaunchOrAttach = core.MustLaunchOrAttach MustLaunchPersistent = core.MustLaunchPersistent MustNew = core.MustNew MustNewBrowserPool = core.MustNewBrowserPool New = core.New NewBrowserPool = core.NewBrowserPool ParseBrowser = core.ParseBrowser ParseProtocol = core.ParseProtocol PiercingClick = core.PiercingClick PiercingDocument = core.PiercingDocument PiercingInputCheckbox = core.PiercingInputCheckbox PiercingNodeBox = core.PiercingNodeBox PiercingRoleCheckbox = core.PiercingRoleCheckbox PiercingTagWithAttr = core.PiercingTagWithAttr RegisterFactory = core.RegisterFactory RetryOnce = core.RetryOnce RetryUnlimited = core.RetryUnlimited RetryUpTo = core.RetryUpTo SupportedCombos = core.SupportedCombos WithBrowserPoolFactory = core.WithBrowserPoolFactory WithBrowserPoolHealthCheck = core.WithBrowserPoolHealthCheck WithBrowserPoolLaunchOptions = core.WithBrowserPoolLaunchOptions WithBrowserPoolPrewarm = core.WithBrowserPoolPrewarm WithClickButton = core.WithClickButton WithClickCount = core.WithClickCount WithClickDelay = core.WithClickDelay WithClickPosition = core.WithClickPosition WithContextEnv = core.WithContextEnv WithContextName = core.WithContextName WithContinueHeaders = core.WithContinueHeaders WithContinueMethod = core.WithContinueMethod WithContinuePostData = core.WithContinuePostData WithContinueURL = core.WithContinueURL WithFingerprintAudioContext = core.WithFingerprintAudioContext WithFingerprintAudioNoise = core.WithFingerprintAudioNoise WithGotoTimeout = core.WithGotoTimeout WithInitialURL = core.WithInitialURL WithInterceptFilter = core.WithInterceptFilter WithInterceptMethods = core.WithInterceptMethods WithInterceptPhases = core.WithInterceptPhases WithInterceptResourceTypes = core.WithInterceptResourceTypes WithInterceptStatusRange = core.WithInterceptStatusRange WithInterceptStatuses = core.WithInterceptStatuses WithMonitorToken = core.WithMonitorToken WithPDFLandscape = core.WithPDFLandscape WithPDFMargins = core.WithPDFMargins WithPDFPageRanges = core.WithPDFPageRanges WithPDFPaperSize = core.WithPDFPaperSize WithPDFPrintBackground = core.WithPDFPrintBackground WithPDFScale = core.WithPDFScale WithPageDefaultTimeout = core.WithPageDefaultTimeout WithPageEnv = core.WithPageEnv WithPageGotoTimeout = core.WithPageGotoTimeout WithPageInitialURL = core.WithPageInitialURL WithPageRetryPolicy = core.WithPageRetryPolicy WithPageWaitUntil = core.WithPageWaitUntil WithPressDelay = core.WithPressDelay WithRoleCaseSensitive = core.WithRoleCaseSensitive WithRoleExact = core.WithRoleExact WithRoleName = core.WithRoleName WithScreenshotClip = core.WithScreenshotClip WithScreenshotFullPage = core.WithScreenshotFullPage WithScreenshotQuality = core.WithScreenshotQuality WithScreenshotSelector = core.WithScreenshotSelector WithScreenshotType = core.WithScreenshotType WithScriptTagAsync = core.WithScriptTagAsync WithScriptTagContent = core.WithScriptTagContent WithScriptTagDefer = core.WithScriptTagDefer WithScriptTagType = core.WithScriptTagType WithScriptTagURL = core.WithScriptTagURL WithSetContentTimeout = core.WithSetContentTimeout WithSetContentWaitUntil = core.WithSetContentWaitUntil WithSkipActionability = core.WithSkipActionability WithStyleTagContent = core.WithStyleTagContent WithStyleTagMedia = core.WithStyleTagMedia WithStyleTagURL = core.WithStyleTagURL WithTraceFileMaxBackups = core.WithTraceFileMaxBackups WithTraceFileMaxBytes = core.WithTraceFileMaxBytes WithTraceFileRotateDaily = core.WithTraceFileRotateDaily WithTypeDelay = core.WithTypeDelay WithWaitUntil = core.WithWaitUntil )
Functions ¶
This section is empty.
Types ¶
type ActionChain ¶
type ActionChain = core.ActionChain
type AfterClickHook ¶
type AfterClickHook = core.AfterClickHook
type ArtifactsLevel ¶
type ArtifactsLevel = core.ArtifactsLevel
type BatchEvalItem ¶
type BatchEvalItem = core.BatchEvalItem
type BatchEvalOp ¶
type BatchEvalOp = core.BatchEvalOp
type BatchEvalResult ¶
type BatchEvalResult = core.BatchEvalResult
type BeforeNavigateHook ¶
type BeforeNavigateHook = core.BeforeNavigateHook
type BrowserPool ¶
type BrowserPool = core.BrowserPool
type BrowserPoolFactory ¶
type BrowserPoolFactory = core.BrowserPoolFactory
type BrowserPoolHealthCheck ¶
type BrowserPoolHealthCheck = core.BrowserPoolHealthCheck
type BrowserPoolOption ¶
type BrowserPoolOption = core.BrowserPoolOption
type BrowserPoolOptions ¶
type BrowserPoolOptions = core.BrowserPoolOptions
type BrowserPoolStats ¶
type BrowserPoolStats = core.BrowserPoolStats
type CDPBudgetStats ¶
type CDPBudgetStats = core.CDPBudgetStats
type CDPControlPath ¶
type CDPControlPath = core.CDPControlPath
type CDPReconnectStats ¶
type CDPReconnectStats = core.CDPReconnectStats
type CDPSessionKind ¶
type CDPSessionKind = core.CDPSessionKind
type CDPTransportStats ¶
type CDPTransportStats = core.CDPTransportStats
type CallRetryMode ¶
type CallRetryMode = core.CallRetryMode
type Capabilities ¶
type Capabilities = core.Capabilities
type CleanupPolicy ¶
type CleanupPolicy = core.CleanupPolicy
type ClickOption ¶
type ClickOption = core.ClickOption
type ClickOptions ¶
type ClickOptions = core.ClickOptions
type CloseAction ¶
type CloseAction = core.CloseAction
type CloseReport ¶
type CloseReport = core.CloseReport
type ConsoleMessage ¶
type ConsoleMessage = core.ConsoleMessage
type ContextOption ¶
type ContextOption = core.ContextOption
type ContextOptions ¶
type ContextOptions = core.ContextOptions
type ContinueOption ¶
type ContinueOption = core.ContinueOption
type ContinueOptions ¶
type ContinueOptions = core.ContinueOptions
type CookieCleanupPreset ¶
type CookieCleanupPreset = core.CookieCleanupPreset
type CookieInput ¶
type CookieInput = core.CookieInput
type CookieSelector ¶
type CookieSelector = core.CookieSelector
type DialogEvent ¶
type DialogEvent = core.DialogEvent
type DownloadEvent ¶
type DownloadEvent = core.DownloadEvent
type DownloadManager ¶
type DownloadManager = core.DownloadManager
type ElementWaiter ¶
type ElementWaiter = core.ElementWaiter
type EmulatedColorScheme ¶
type EmulatedColorScheme = core.EmulatedColorScheme
type EmulatedForcedColors ¶
type EmulatedForcedColors = core.EmulatedForcedColors
type EmulatedReducedMotion ¶
type EmulatedReducedMotion = core.EmulatedReducedMotion
type EmulationManager ¶
type EmulationManager = core.EmulationManager
type EngineDiagnostics ¶
type EngineDiagnostics = core.EngineDiagnostics
type EngineOwnership ¶
type EngineOwnership = core.EngineOwnership
type EnvProfile ¶
type EnvProfile = core.EnvProfile
type ExposedFunction ¶
type ExposedFunction = core.ExposedFunction
type FileDialogEvent ¶
type FileDialogEvent = core.FileDialogEvent
type FingerprintAudioOption ¶
type FingerprintAudioOption = core.FingerprintAudioOption
type FingerprintMode ¶
type FingerprintMode = core.FingerprintMode
type FingerprintWebRTCMode ¶
type FingerprintWebRTCMode = core.FingerprintWebRTCMode
type FulfillResponse ¶
type FulfillResponse = core.FulfillResponse
type Geolocation ¶
type Geolocation = core.Geolocation
type GotoOption ¶
type GotoOption = core.GotoOption
type GotoOptions ¶
type GotoOptions = core.GotoOptions
type HistoryLimits ¶
type HistoryLimits = core.HistoryLimits
type IndexedDBDatabase ¶
type IndexedDBDatabase = core.IndexedDBDatabase
type IndexedDBRecord ¶
type IndexedDBRecord = core.IndexedDBRecord
type IndexedDBScope ¶
type IndexedDBScope = core.IndexedDBScope
type InterceptEvent ¶
type InterceptEvent = core.InterceptEvent
type InterceptFilter ¶
type InterceptFilter = core.InterceptFilter
type InterceptHandler ¶
type InterceptHandler = core.InterceptHandler
type InterceptManager ¶
type InterceptManager = core.InterceptManager
type InterceptOption ¶
type InterceptOption = core.InterceptOption
type InterceptOptions ¶
type InterceptOptions = core.InterceptOptions
type InterceptPhase ¶
type InterceptPhase = core.InterceptPhase
type InterceptedRequest ¶
type InterceptedRequest = core.InterceptedRequest
type InternalOpStats ¶
type InternalOpStats = core.InternalOpStats
type LaunchArgsPolicy ¶
type LaunchArgsPolicy = core.LaunchArgsPolicy
type LaunchMode ¶
type LaunchMode = core.LaunchMode
type LaunchOption ¶
type LaunchOption = core.LaunchOption
type MobilePreset ¶
type MobilePreset = core.MobilePreset
type MonitorServeOption ¶
type MonitorServeOption = core.MonitorServeOption
type MonitorServeOptions ¶
type MonitorServeOptions = core.MonitorServeOptions
type MonitorServer ¶
type MonitorServer = core.MonitorServer
type MonitorSnapshot ¶
type MonitorSnapshot = core.MonitorSnapshot
type MouseButton ¶
type MouseButton = core.MouseButton
type NavigationAction ¶
type NavigationAction = core.NavigationAction
type NavigationEvent ¶
type NavigationEvent = core.NavigationEvent
type NavigationManager ¶
type NavigationManager = core.NavigationManager
type NetworkFilter ¶
type NetworkFilter = core.NetworkFilter
type NetworkManager ¶
type NetworkManager = core.NetworkManager
type NetworkPacket ¶
type NetworkPacket = core.NetworkPacket
type NetworkResponseData ¶
type NetworkResponseData = core.NetworkResponseData
type NetworkTransaction ¶
type NetworkTransaction = core.NetworkTransaction
type PDFOptions ¶
type PDFOptions = core.PDFOptions
type PacketType ¶
type PacketType = core.PacketType
type PageCreatedHook ¶
type PageCreatedHook = core.PageCreatedHook
type PageDiagnostics ¶
type PageDiagnostics = core.PageDiagnostics
type PageEnvironment ¶
type PageEnvironment = core.PageEnvironment
type PageInteraction ¶
type PageInteraction = core.PageInteraction
type PageLifecycle ¶
type PageLifecycle = core.PageLifecycle
type PageManagers ¶
type PageManagers = core.PageManagers
type PageNavigation ¶
type PageNavigation = core.PageNavigation
type PageNetworkControl ¶
type PageNetworkControl = core.PageNetworkControl
type PageOption ¶
type PageOption = core.PageOption
type PageOptions ¶
type PageOptions = core.PageOptions
type PageWaiter ¶
type PageWaiter = core.PageWaiter
type PiercingBox ¶
type PiercingBox = core.PiercingBox
type PiercingNode ¶
type PiercingNode = core.PiercingNode
type PooledEngine ¶
type PooledEngine = core.PooledEngine
type PressOption ¶
type PressOption = core.PressOption
type PressOptions ¶
type PressOptions = core.PressOptions
type ProtocolEvent ¶
type ProtocolEvent = core.ProtocolEvent
type RaceBuilder ¶
type RaceBuilder = core.RaceBuilder
type RaceElementBuilder ¶
type RaceElementBuilder = core.RaceElementBuilder
type RaceResult ¶
type RaceResult = core.RaceResult
type ReconnectPolicy ¶
type ReconnectPolicy = core.ReconnectPolicy
type RedirectResponse ¶
type RedirectResponse = core.RedirectResponse
type RequestEvent ¶
type RequestEvent = core.RequestEvent
type ResponseEvent ¶
type ResponseEvent = core.ResponseEvent
type RetryPolicy ¶
type RetryPolicy = core.RetryPolicy
type RoleOption ¶
type RoleOption = core.RoleOption
type RoleOptions ¶
type RoleOptions = core.RoleOptions
type RouteHandler ¶
type RouteHandler = core.RouteHandler
type RoutePauseStage ¶
type RoutePauseStage = core.RoutePauseStage
type ScreenshotOption ¶
type ScreenshotOption = core.ScreenshotOption
type ScreenshotOptions ¶
type ScreenshotOptions = core.ScreenshotOptions
type ScriptTagOption ¶
type ScriptTagOption = core.ScriptTagOption
type ScriptTagOptions ¶
type ScriptTagOptions = core.ScriptTagOptions
type SetContentOption ¶
type SetContentOption = core.SetContentOption
type SetContentOptions ¶
type SetContentOptions = core.SetContentOptions
type SignalHandlingMode ¶
type SignalHandlingMode = core.SignalHandlingMode
type StorageManager ¶
type StorageManager = core.StorageManager
type StorageScope ¶
type StorageScope = core.StorageScope
type StyleTagOption ¶
type StyleTagOption = core.StyleTagOption
type StyleTagOptions ¶
type StyleTagOptions = core.StyleTagOptions
type Subscription ¶
type Subscription = core.Subscription
type TraceEvent ¶
type TraceEvent = core.TraceEvent
type TraceFileOption ¶
type TraceFileOption = core.TraceFileOption
type TraceFileOptions ¶
type TraceFileOptions = core.TraceFileOptions
type TypeOption ¶
type TypeOption = core.TypeOption
type TypeOptions ¶
type TypeOptions = core.TypeOptions
type UnsupportedComboError ¶
type UnsupportedComboError = core.UnsupportedComboError
type WindowBounds ¶
type WindowBounds = core.WindowBounds
type WindowManager ¶
type WindowManager = core.WindowManager
type WindowState ¶
type WindowState = core.WindowState
Directories
¶
| Path | Synopsis |
|---|---|
|
Package cfsolver wraps go-bot's piercing primitives with a single high-level call that drives the page through a Cloudflare interstitial or Turnstile challenge.
|
Package cfsolver wraps go-bot's piercing primitives with a single high-level call that drives the page through a Cloudflare interstitial or Turnstile challenge. |
|
examples
|
|
|
actions_chain
command
|
|
|
basic
command
|
|
|
browser_pool
command
|
|
|
cdp_cf_interstitial_tgjones
command
Example: solve the Cloudflare interstitial on tgjonesonline.co.uk.
|
Example: solve the Cloudflare interstitial on tgjonesonline.co.uk. |
|
cdp_cf_turnstile_click
command
|
|
|
cdp_chromium_screenshot
command
|
|
|
cdp_cookies_download
command
|
|
|
cdp_dialog
command
|
|
|
cdp_element_query_wait
command
|
|
|
cdp_elements
command
|
|
|
cdp_navigation_content
command
|
|
|
cdp_navigation_request_listen
command
|
|
|
cdp_network_control_body
command
|
|
|
cdp_network_hooks
command
|
|
|
cdp_pdf_screenshot
command
|
|
|
cdp_upload_press
command
|
|
|
downloads_manager
command
|
|
|
element_facade
command
|
|
|
emulation_manager
command
|
|
|
fingerprint_custom
command
|
|
|
fingerprint_register
command
|
|
|
frame_scope
command
|
|
|
intercept_manager
command
|
|
|
locator_nth
command
|
|
|
locator_shadow_chain
command
|
|
|
locator_tree
command
|
|
|
monitor_trace
command
|
|
|
navigation_manager
command
|
|
|
network_manager
command
|
|
|
shadow_root
command
|
|
|
storage_manager
command
|
|
|
window_manager
command
|
|
|
internal
|
|
Click to show internal directories.
Click to hide internal directories.